==> ntropy_ai-0.0.3a0.tar.gz: ntropy_ai-0.0.3a0/README.md <==
<h1 align="center">Welcome to ntropy-ai 👋</h1>
<p>
  <a href="https://ntropy-ai.gitbook.io/ntropy-ai-python-lib-docs" target="_blank">
    <img alt="Documentation" src="https://img.shields.io/badge/documentation-yes-brightgreen.svg" />
  </a>
  <a href="https://github.com/ntropy-ai/ntropy/blob/main/LICENSE.txt" target="_blank">
    <img alt="License: AGPL--3.0 " src="https://img.shields.io/badge/License-AGPL--3.0 -yellow.svg" />
  </a>
  <a href="https://twitter.com/hugolb05" target="_blank">
    <img alt="Twitter: hugolb05" src="https://img.shields.io/twitter/follow/hugolb05.svg?style=social" />
  </a>
    <a href="https://x.com/ZorkotDasha" target="_blank">
    <img alt="Twitter: ZorkotDasha" src="https://img.shields.io/twitter/follow/ZorkotDasha.svg?style=social" />
  </a>
</p>

> Unleash the power of multimodal agents

## Install

```sh
pip install ntropy-ai
```

## Authors

👤 **Hugo Le Belzic & Darya Todoskova**

* Twitter: [@hugolb05](https://twitter.com/hugolb05) & [@ZorkotDasha](https://twitter.com/ZorkotDasha)
* Github: [@HugoLB0](https://github.com/HugoLB0) & [@zorkotdasha](https://github.com/zorkotdasha)
* LinkedIn: [@hugolebelzic](https://linkedin.com/in/hugolebelzic) & [@zorkotdasha](https://www.linkedin.com/in/darya-todoskova-zorkot-3005181b8/)

## 🤝 Contributing

Contributions, issues and feature requests are welcome!<br />Feel free to check [issues page](https://github.com/ntropy-ai/ntropy/issues). 

## Show your support

Give a ⭐️ if this project helped you!

## 📝 License

Copyright © 2024 [Hugo Le Belzic](https://github.com/HugoLB0) & [Darya Todoskova](https://github.com/zorkotdasha).<br />
This project is [AGPL--3.0 ](https://github.com/ntropy-ai/ntropy/blob/main/LICENSE.txt) licensed.

==> ntropy_ai-0.0.5a0.tar.gz: ntropy_ai-0.0.5a0/README.md <==
<h1 align="center">Welcome to ntropy-ai 👋</h1>
<p>
  <a href="https://ntropy-ai.gitbook.io/ntropy-ai-python-lib-docs" target="_blank">
    <img alt="Documentation" src="https://img.shields.io/badge/documentation-yes-brightgreen.svg" />
  </a>
  <a href="https://github.com/ntropy-ai/ntropy/blob/main/LICENSE.txt" target="_blank">
    <img alt="License: AGPL--3.0 " src="https://img.shields.io/badge/License-AGPL--3.0 -yellow.svg" />
  </a>
  <a href="https://twitter.com/hugolb05" target="_blank">
    <img alt="Twitter: hugolb05" src="https://img.shields.io/twitter/follow/hugolb05.svg?style=social" />
  </a>
    <a href="https://x.com/ZorkotDasha" target="_blank">
    <img alt="Twitter: ZorkotDasha" src="https://img.shields.io/twitter/follow/ZorkotDasha.svg?style=social" />
  </a>
</p>

> Unleash the power of multimodal agents

## Install

```sh
pip install ntropy-ai
```

## Authors

👤 **Hugo Le Belzic & Darya Todoskova**

* Twitter: [@hugolb05](https://twitter.com/hugolb05) & [@ZorkotDasha](https://twitter.com/ZorkotDasha)
* Github: [@HugoLB0](https://github.com/HugoLB0) & [@zorkotdasha](https://github.com/daryatodoskova)
* LinkedIn: [@hugolebelzic](https://linkedin.com/in/hugolebelzic) & [@zorkotdasha](https://www.linkedin.com/in/darya-todoskova-zorkot-3005181b8/)

## 🤝 Contributing

Contributions, issues and feature requests are welcome!<br />Feel free to check [issues page](https://github.com/ntropy-ai/ntropy/issues). 

## Show your support

Give a ⭐️ if this project helped you!

## 📝 License

Copyright © 2024 [Hugo Le Belzic](https://github.com/HugoLB0) & [Darya Todoskova](https://github.com/daryatodoskova).<br />
This project is [AGPL--3.0 ](https://github.com/ntropy-ai/ntropy/blob/main/LICENSE.txt) licensed.
